@@ -56,6 +56,8 @@ PACKET_RFDEBUGN = DELIM.join(['20', SEQUENCE, 'RFDEBUG=ON'])
 PACKET_RFDEBUGF = DELIM.join(['20', SEQUENCE, 'RFDEBUG=OFF'])
 PACKET_RFUDEBUGN = DELIM.join(['20', SEQUENCE, 'RFUDEBUG=ON'])
 PACKET_RFUDEBUGF = DELIM.join(['20', SEQUENCE, 'RFUDEBUG=OFF'])
+PACKET_QRFDEBUGN = DELIM.join(['20', SEQUENCE, 'QRFDEBUG=ON'])
+PACKET_QRFDEBUGF = DELIM.join(['20', SEQUENCE, 'QRFDEBUG=OFF'])
 
 # 11;20;0B;NewKaku;ID=000005;SWITCH=2;CMD=ON;
 PACKET_DEVICE_CREATE = '11;' + PACKET_DEVICE
@@ -63,7 +65,8 @@ PACKET_DEVICE_CREATE = '11;' + PACKET_DEVICE
 PACKET_HEADER_RE = '^(' + '|'.join(
     [PACKET_VERSION, PACKET_DEVICE_CREATE, PACKET_RESPONSE, PACKET_DEVICE,
      PACKET_COMMAND, PACKET_COMMAND2, PACKET_COMMAND3, PACKET_COMMAND4, PACKET_CONTROL,
-     PACKET_DEBUG, PACKET_RFDEBUGN, PACKET_RFUDEBUGN, PACKET_RFDEBUGF, PACKET_RFUDEBUGF ]) + ');$'
+     PACKET_DEBUG, PACKET_RFDEBUGN, PACKET_RFUDEBUGN, PACKET_RFDEBUGF, PACKET_RFUDEBUGF,
+     PACKET_QRFDEBUGN, PACKET_QRFDEBUGF]) + ');$'
 packet_header_re = re.compile(PACKET_HEADER_RE)
 
 
@@ -308,7 +311,9 @@ def encode_packet(packet: dict) -> str:
     if packet['protocol'] == 'rfdebug':
         return '10;RFDEBUG=' + packet['command'] + ';'
     elif packet['protocol'] == 'rfudebug':
-        return '10;RFDEBUG=' + packet['command'] + ';'
+        return '10;RFUDEBUG=' + packet['command'] + ';'
+    elif packet['protocol'] == 'qrfdebug':
+        return '10;QRFDEBUG=' + packet['command'] + ';'
     else:
         return SWITCH_COMMAND_TEMPLATE.format(
             node=PacketHeader.master.value,
@@ -458,7 +463,7 @@ def packet_events(packet: dict) -> Generator:
     ... }))
     >>> assert {'id': 'newkaku_000001_01', 'command': 'on'} in y
     """
-    field_abbrev = {v: k for k, v in PACKET_FIELDS.items()}
+    field_abbrev = {v: k for k, v in sorted(PACKET_FIELDS.items(), key=lambda x: (x[1], x[0]), reverse=True)}
 
     packet_id = serialize_packet_id(packet)
     events = {f: v for f, v in packet.items() if f in field_abbrev}
